@@ -13,7 +13,7 @@ import pandas as pd
 #import error_controller
 #from mstrio.utils.error_handlers import ErrorHandler
 from mstr_robotics.helper import str_func
-from mstr_robotics import logger
+from mstr_robotics.logger import logger
 
 str_func=str_func
 log=logger
